@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module WebConsole
   # Simple Ruby code evaluator.
   #
@@ -8,7 +10,7 @@ module WebConsole
     # Cleanses exceptions raised inside #eval.
     cattr_reader :cleaner
     @@cleaner = ActiveSupport::BacktraceCleaner.new
-    @@cleaner.add_silencer { |line| line.start_with?(File.expand_path('..', __FILE__)) }
+    @@cleaner.add_silencer { |line| line.start_with?(File.expand_path("..", __FILE__)) }
 
     def initialize(binding = TOPLEVEL_BINDING)
       @binding = binding
@@ -25,7 +27,7 @@ module WebConsole
       def format_exception(exc)
         backtrace = cleaner.clean(Array(exc.backtrace) - caller)
 
-        format = "#{exc.class.name}: #{exc}\n"
+        format = "#{exc.class.name}: #{exc}\n".dup
         format << backtrace.map { |trace| "\tfrom #{trace}\n" }.join
         format
       end
